/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata;

import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import static com.trifork.stamdata.Preconditions.checkNotNull;

public final class ConfigurationLoader {
    private static final Logger logger = Logger.getLogger(ConfigurationLoader.class);

    protected ConfigurationLoader() {
    }

    public static Properties loadForName(String componentName) {
        checkNotNull(componentName, "componentName");

        // LOAD CONFIGURATION FILES

        ClassLoader classLoader = ConfigurationLoader.class.getClassLoader();

        InputStream buildInConfig = classLoader.getResourceAsStream("config.properties");
        InputStream testConfig = classLoader.getResourceAsStream("test-config.properties");
        InputStream deploymentConfig = classLoader.getResourceAsStream(componentName + ".properties");

        final Properties config = new Properties();

        try {
        	if (System.getProperty("jboss.server.config.dir") != null) {
        		FileInputStream fis = new FileInputStream(System.getProperty("jboss.server.config.dir") + "/" + componentName + ".properties");
        		if (fis != null) {
        			deploymentConfig = fis;
        		}
        	}

            config.load(buildInConfig);
            logger.debug("Configuration file 'config.properties' loaded");
            buildInConfig.close();

            if (testConfig != null) {
                logger.info("Test Configuration file 'test-config.properties' found.");

                config.load(testConfig);
            }

            if (deploymentConfig != null) {
                logger.info("Configuration file '"+componentName+".properties' found.");

                config.load(deploymentConfig);
            } else {
                logger.warn("Could not find "+componentName+".properties. Using default configuration.");
            }
        } catch (IOException e) {
            throw new RuntimeException("Problem loading the component's configuration files. component=" + componentName, e);
        } finally {
            IOUtils.closeQuietly(buildInConfig);
            IOUtils.closeQuietly(testConfig);
            IOUtils.closeQuietly(deploymentConfig);
        }

        return config;
    }
}
