/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.jaxws;

import java.util.Set;

import javax.xml.namespace.QName;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeader;
import javax.xml.ws.handler.MessageContext;
import javax.xml.ws.handler.soap.SOAPHandler;
import javax.xml.ws.handler.soap.SOAPMessageContext;

import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import dk.sosi.seal.model.constants.FlowStatusValues;

public class DGWSSoapHandler implements SOAPHandler<SOAPMessageContext> {

    @Override
    public boolean handleMessage(SOAPMessageContext ctx) {
        try {
            Boolean isOutbound = (Boolean)ctx.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
            
            if(isOutbound.booleanValue()) {
                SOAPHeader soapHeader = ctx.getMessage().getSOAPHeader();

                NodeList nodeList = soapHeader.getElementsByTagNameNS("http://www.medcom.dk/dgws/2006/04/dgws-1.0.xsd", "Header");
                Node medcomHeader = nodeList.item(0);

                // SDM-50 For mange FlowStatus elementer
                // Fjern flowstatus fra clienten så vi ikke får 2 i svaret
                NodeList medcomHeaderChildNodes = medcomHeader.getChildNodes();
                for (int i=0; i<medcomHeaderChildNodes.getLength(); ++i) {
                    Node child = medcomHeaderChildNodes.item(i);
                    if (child.getNodeType() == Node.ELEMENT_NODE && child.getLocalName().equals("FlowStatus")) {
                        medcomHeader.removeChild(child);
                        break;
                    }
                }

                // If client did not supply a flow status create a new flow status element
                Element flowStatus = medcomHeader.getOwnerDocument().createElementNS("http://www.medcom.dk/dgws/2006/04/dgws-1.0.xsd", "FlowStatus");
                flowStatus.setTextContent(FlowStatusValues.FLOW_FINALIZED_SUCCESFULLY);

                NodeList linking = soapHeader.getElementsByTagNameNS("http://www.medcom.dk/dgws/2006/04/dgws-1.0.xsd", "Linking");
                Node nextSibling = ((Element)linking.item(0)).getNextSibling();
                if(nextSibling == null) {
                    medcomHeader.appendChild(flowStatus);
                } else {
                    medcomHeader.insertBefore(flowStatus, nextSibling);
                }
            }
            
        } catch (SOAPException e) {
            return false;
        }
        return true;
    }
    
    @Override
    public Set<QName> getHeaders() {
        return null;
    }

    @Override
    public void close(MessageContext ctx) {
    }

    @Override
    public boolean handleFault(SOAPMessageContext ctx) {
        return true;
    }
    
}
