/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.jaxws;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import javax.xml.namespace.QName;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeader;
import javax.xml.ws.handler.MessageContext;
import javax.xml.ws.handler.soap.SOAPHandler;
import javax.xml.ws.handler.soap.SOAPMessageContext;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;


public class SealNamespacePrefixSoapHandler implements SOAPHandler<SOAPMessageContext>
{
    @Override
    public Set<QName> getHeaders()
    {
        return null;
    }


    @Override
    public boolean handleMessage(SOAPMessageContext context)
    {
        try
        {
            SOAPHeader soapHeader = context.getMessage().getSOAPHeader();

            for (Map.Entry<String, String> prefixMapEntry : SealNamespacePrefixMapper.PREFIX_MAP.entrySet())
            {
                soapHeader.addNamespaceDeclaration(prefixMapEntry.getValue(), prefixMapEntry.getKey());
            }
            
            for (Iterator<?> iterator = soapHeader.examineAllHeaderElements(); iterator.hasNext();)
            {
                Node element = (Node) iterator.next();
                changePrefix(element.getChildNodes());
            }
        }
        catch (SOAPException e)
        {
            return false;
        }

        return true;
    }


    private void changePrefix(NodeList elementsToProcess)
    {
        for (int i = 0; i < elementsToProcess.getLength(); i++)
        {
            Node node = elementsToProcess.item(i);
            String nodeNS = node.getNamespaceURI();
            if (SealNamespacePrefixMapper.PREFIX_MAP.containsKey(nodeNS))
            {
                node.setPrefix(SealNamespacePrefixMapper.PREFIX_MAP.get(nodeNS));
            }

            changePrefix(node.getChildNodes());
        }
    }


    @Override
    public boolean handleFault(SOAPMessageContext context)
    {
        return true;
    }


    @Override
    public void close(MessageContext context)
    {
    }
}
