/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.sla;

import dk.sdsd.nsp.slalog.api.SLALogConfig;
import dk.sdsd.nsp.slalog.api.SLALogConfigException;
import dk.sdsd.nsp.slalog.api.SLALogItem;
import dk.sdsd.nsp.slalog.ws.SLALoggingServletFilter;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;

public class SDMSLALoggingFilter extends SLALoggingServletFilter {
    private static final Logger log = Logger.getLogger(SDMSLALoggingFilter.class);
    private SLALogConfig slaLogInstance;
    private String shortAppName;

    public void init(FilterConfig filterConfig) throws ServletException {
        String appName = filterConfig.getInitParameter("appName");
        shortAppName = filterConfig.getInitParameter("shortAppName");

        try {
            slaLogInstance = new SLALogConfig(appName, shortAppName);
        } catch (SLALogConfigException e) {
            log.error("Could not configure SLA logging for application " + appName, e);
        }
    }

    protected SLALogItem createLogItem(HttpServletRequest servletRequest) {
        String soapActionHeader = servletRequest.getHeader("SOAPAction");
        String soapAction = (soapActionHeader != null) ? StringUtils.strip(soapActionHeader, "\"") : "";
        String trimmedRequestURI = StringUtils.strip(servletRequest.getRequestURI(), "/");
        String[] uriParts = StringUtils.split(trimmedRequestURI, "/");
        String operation = uriParts[uriParts.length-1];
        String logPoint = shortAppName + "." + operation;

        SLALogItem logItem = null;
        if (slaLogInstance != null) {
            try {
                logItem = slaLogInstance.getSLALogger().createLogItem(logPoint, shortAppName + "." + operation);
                logItem.setClientIP(servletRequest);
                logItem.setSourceSOAPAction(soapAction);
                logItem.setSourceOperation(operation);
                logItem.setSourceEndpoint(servletRequest.getRequestURL().toString());
            } catch (Exception e) {
                log.error("Could not instantiate SLA log item", e);
            }
        } // error situation causing slaLogInstance to be null has already been error-logged in init, so just ignore silently
        return logItem;
    }

}
