/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.security;

import static dk.sosi.seal.model.constants.SubjectIdentifierTypeValues.CVR_NUMBER;

import javax.servlet.http.HttpServletRequest;

import com.google.inject.AbstractModule;
import com.google.inject.Provides;
import com.google.inject.servlet.RequestScoped;

import dk.sdsd.nsp.slalog.api.SLALogItem;
import dk.sdsd.nsp.slalog.ws.SLALoggingServletFilter;
import dk.sosi.seal.model.SystemIDCard;

public class DenGodeWebServiceModule extends AbstractModule {
    @Override
    protected void configure() {
        // Nothing to do
    }


    @Provides
    @RequestScoped
    public SystemIDCard provideSystemIDCard(HttpServletRequest request)  {
        return (SystemIDCard) request.getAttribute(DenGodeWebServiceFilter.IDCARD_REQUEST_ATTRIBUTE_KEY);
    }

    @Provides
    @RequestScoped
    public SLALogItem provideCurrentSlaLogItem(HttpServletRequest request) {
        return (SLALogItem) request.getAttribute(SLALoggingServletFilter.CURRENT_LOGITEM_REQUEST_KEY);
    }
    
    @Provides
    @RequestScoped
    @ClientVocesCvr
    public String providesClientVocesCVR(SystemIDCard idCard) {
        if (!idCard.getSystemInfo().getCareProvider().getType().equals(CVR_NUMBER)) {
            throw new IllegalStateException("You cannot inject a client's VOCES CVR if the suplied id card is not using a CVR care provider.");
        }
        
        return idCard.getSystemInfo().getCareProvider().getID();
    }
}
