/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.testing;

import java.util.List;

import org.junit.runner.notification.RunNotifier;
import org.junit.runners.BlockJUnit4ClassRunner;
import org.junit.runners.model.FrameworkMethod;
import org.junit.runners.model.InitializationError;

import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.Module;


public abstract class AbstractGuiceTestRunner extends BlockJUnit4ClassRunner
{
    private final Injector injector;


    /**
     * Creates a new GuiceTestRunner.
     * 
     * @param classToRun the test class to run
     * @param modules the Guice modules
     * @throws InitializationError if the test class is malformed
     */
    protected AbstractGuiceTestRunner(final Class<?> classToRun, Module... modules) throws InitializationError
    {
        super(classToRun);
        this.injector = Guice.createInjector(modules);
    }


    @Override
    public Object createTest()
    {
        return injector.getInstance(getTestClass().getJavaClass());
    }


    @Override
    protected void validateZeroArgConstructor(List<Throwable> errors)
    {
        // Guice can inject constructors with parameters so we don't want this
        // method to trigger an error
    }


    /**
     * Returns the Guice injector.
     * 
     * @return the Guice injector
     */
    protected Injector getInjector()
    {
        return injector;
    }
    
    @Override
    protected void runChild(FrameworkMethod method, RunNotifier notifier)
    {
        super.runChild(method, notifier);
    }
}
