/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.testing;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.net.URL;
import java.util.Properties;

public class TestHelper {


	private PrintStream originalSystemOut = System.out;
	private ByteArrayOutputStream outStream = new ByteArrayOutputStream();

	public void resetSystemOut() {
		System.setOut(originalSystemOut);
        if (!outStream.toString().trim().isEmpty()) {
            System.out.println(outStream);
        }
	}

	public ByteArrayOutputStream redirectSystemOutToStream() {
		outStream = new ByteArrayOutputStream();
    	PrintStream out = new PrintStream(outStream);
    	System.setOut(out);
		return outStream;
	}

	public void enableAuditlogging(Boolean enable) {
		System.setProperty("dk.sds.nsp.audit.DevelopmentAuditProvider.enabled", (enable) ? "true" : "false");
	}

	public String[] getSystemLogs() {
	    String[] logs = outStream.toString().split(System.lineSeparator());
	    return logs;
	}

	public String getSystemLogs(String containing) {
	    String[] logs = outStream.toString().split(System.lineSeparator());
	    for (String log : logs) {
	        if (log.indexOf(containing) >= 0) {
	            return log;
	        }
	    }
	    return "";
	}

	public String getSystemOut() {
        return outStream.toString();
	}

    public static Properties loadProperties(Class class1) throws Exception {
        Properties properties = new Properties();
        ClassLoader loader = class1.getClassLoader();
        URL url = loader.getResource("test-config.properties");
        assert url != null;
        properties.load(url.openStream());

        return properties;
    }
}
