/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.testing;

import java.io.File;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.nio.SelectChannelConnector;
import org.mortbay.jetty.webapp.WebAppContext;
import static org.junit.Assert.assertTrue;


public class TestServer
{
    private Server server;
    private String contextPath = "/";
    private int port = 8972;
    private String warPath = "src/main/webapp/";

    public TestServer()
    {
        server = new Server();
    }


    public TestServer start() throws Exception
    {
        WebAppContext context = new WebAppContext();

        SelectChannelConnector connector = new SelectChannelConnector();
        connector.setPort(port);

        File war = new File("." , warPath);
        assertTrue(new File(war, "WEB-INF/web.xml").getAbsolutePath(), new File(war, "WEB-INF/web.xml").exists());
        System.out.println("webapp: " + war.getAbsolutePath());
        
        context.setWar(war.getAbsolutePath());

        context.setContextPath(contextPath);
        server.setHandler(context);
        server.addConnector(connector);
        server.start();

        if (server.isFailed())
        {
            throw new IllegalStateException("Failed to start the test server. Check the log.");
        }

        return this;
    }


    public TestServer port(int port)
    {
        this.port = port;

        return this;
    }


    public TestServer contextPath(String contextPath)
    {
        this.contextPath = contextPath;

        return this;
    }
    
    public TestServer warPath(String warPath)
    {
        this.warPath = warPath;
        
        return this;
    }

    public String warPath()
    {
        return warPath;
    }


    public void stop() throws Exception
    {
        if (server != null && server.isRunning())
        {
            server.stop();
        }

        server.destroy();
        server = null;
    }

    public void join() throws InterruptedException
    {
        server.join();
    }
}
