/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.replication.dynamic;

import dk.nsi.stamdata.replication.exceptions.DynamicViewException;
import dk.nsi.stamdata.replication.vo.ColumnMapVO;
import dk.nsi.stamdata.replication.vo.ViewMapVO;

import java.sql.Timestamp;
import java.util.Map;

public class DynamicRow {

    private Map<String,Object> content;
    private final ViewMapVO view;

    public DynamicRow(ViewMapVO view, Map<String, Object> content) {
        this.content = content;
        this.view = view;
    }

    public Map<String, Object> getContent() {
        return content;
    }

    public Timestamp getValidTo() {
        Timestamp result = (Timestamp) content.get("ValidTo");
        if (result == null) {
            result = (Timestamp) content.get("validTo");
        }
        return result;
    }

    public Timestamp getValidFrom() {
        Timestamp result = (Timestamp) content.get("ValidFrom");
        if (result == null) {
            result = (Timestamp) content.get("validFrom");
        }
        return result;
    }

    public Timestamp getModifiedDate() {
        Timestamp result = (Timestamp) content.get("ModifiedDate");
        if (result == null) {
            result = (Timestamp) content.get("modifiedDate");
        }
        return result;
    }

    public long getPid() {
        for (ColumnMapVO column : view.getColumnMaps()) {
            if (column.isPid()) {
                return (Long) content.get(column.getTableColumnName());
            }
        }
        throw new DynamicViewException("Could not find pid column in viewMap:" + view.toString());
    }

}
