/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.replication.dynamic;

import com.google.inject.Inject;
import dk.nsi.stamdata.replication.dao.DynamicViewDAO;
import dk.nsi.stamdata.replication.exceptions.DynamicViewException;
import dk.nsi.stamdata.replication.vo.ViewMapVO;

import java.sql.SQLException;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class DynamicViewMapper {

    private Map<String, Set<ViewMapVO>> viewMaps = new HashMap<String, Set<ViewMapVO>>();

    @Inject
    private DynamicViewDAO dao;

    public ViewMapVO getViewMapForView(String register, String datatype, long version) {
        ViewMapVO result = getViewMapIfExist(register, datatype, version);
        if (result == null) {
            result = createAndAddViewMap(register, datatype, version);
        }
        return result;
    }

    public boolean viewMapExists(String register, String datatype, long version) throws SQLException {
        try {
            dao.getViewMapForView(register, datatype, version);
        } catch (DynamicViewException ignore) {
            return false;
        }
        return true;
    }

    private ViewMapVO getViewMapIfExist(String register, String datatype, long version) {
        Set<ViewMapVO> viewMapVOs = viewMaps.get(register);
        if (viewMapVOs != null) {
            for (ViewMapVO viewMap : viewMapVOs) {
                if (viewMap.getDatatype().equals(datatype) && viewMap.getVersion() == version) {
                    return viewMap;
                }
            }
        }
        return null;
    }

    private ViewMapVO createAndAddViewMap(String register, String datatype, long version) {
        try {
            ViewMapVO viewMap = dao.getViewMapForView(register, datatype, version);
            Set<ViewMapVO> viewMapSet = viewMaps.get(register);
            if (viewMapSet == null) {
                viewMapSet = new HashSet<ViewMapVO>();
            }
            viewMapSet.add(viewMap);
            viewMaps.put(register, viewMapSet);
            return viewMap;
        } catch (SQLException e) {
            throw new DynamicViewException("Failed to load view for register:" + register + " datatype:" + datatype +
                    " version:" + version);
        }
    }

}
