/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsi.stamdata.replication.models;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import com.google.inject.Inject;
import com.google.inject.Provider;
import com.trifork.stamdata.persistence.PersistenceModule;


public class ClientDao
{
    private Provider<Connection> connectionProvider;


    @Inject
    ClientDao(Provider<Connection> connectionProvider)
    {
        this.connectionProvider = connectionProvider;
    }

    public ClientVO findByCvr(String cvr) throws SQLException
    {
        String ssnlike = "CVR:" + cvr + "-%";
        String sql_client = "SELECT id, name, subjectSerialNumber FROM Client WHERE subjectSerialNumber LIKE ?";
        String sql_permissions = "SELECT permissions FROM Client_permissions WHERE client_id = ?";
        ClientVO client = null;
        PreparedStatement preparedStatement = null;
        Connection connection = null;

        try {
            connection = connectionProvider.get();
            preparedStatement = connection.prepareStatement(sql_client);
            int index=1;
            preparedStatement.setObject(index++, ssnlike);
            ResultSet resultSet = preparedStatement.executeQuery();
            while (resultSet.next()) {
                if (!resultSet.isLast()) {
                    throw new IllegalStateException("More that one client returned for single subjectSerialNumber");
                }
                client =  mapClient(resultSet);
            }
            PersistenceModule.close(preparedStatement);
            if (client != null) {
                preparedStatement = connection.prepareStatement(sql_permissions);
                index=1;
                preparedStatement.setObject(index++, client.getId());
                resultSet = preparedStatement.executeQuery();
                while (resultSet.next()) {
                    client.addPermission(resultSet.getString("permissions"));
                }
            }
        } finally {
            PersistenceModule.close(preparedStatement);
            PersistenceModule.close(connection);
        }
        return client;
    }


    private ClientVO mapClient(ResultSet resultSet) throws SQLException {
        ClientVO client = new ClientVO();

        client.setId(resultSet.getString("id"));
        client.setName(resultSet.getString("name"));
        client.setSubjectSerialNumber(resultSet.getString("subjectSerialNumber"));

        return client;
    }
}
