/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.replication.models;

import java.util.Collections;
import java.util.Set;

import com.google.common.collect.Sets;

public class ClientVO
{
	private String id;

	private String name;
	private String subjectSerialNumber;

	private Set<String> permissions = Sets.newHashSet();

	protected ClientVO()
	{

	}

	public void setId(String id) {
        this.id = id;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setSubjectSerialNumber(String subjectSerialNumber) {
        this.subjectSerialNumber = subjectSerialNumber;
    }

    public ClientVO(String name, String subjectSerialNumber)
	{
		this.name = name;
		this.subjectSerialNumber = subjectSerialNumber;
	}

	public String getId()
	{
		return id;
	}

	public String getName()
	{
		return name;
	}

	public String getSubjectSerialNumber()
	{
		return subjectSerialNumber;
	}

	public boolean addPermission(String viewName)
	{
		return permissions.add(viewName);
	}

	public boolean removePermission(String viewName)
	{
		return permissions.remove(viewName);
	}

	public boolean isAuthorizedFor(String viewName)
	{
	    for (String permission : permissions) {
	        if (viewName.startsWith(permission)) {
	            return true;
	        }
	    }
        return false;
	}

	public Set<String> getPermissions()
	{
		return Collections.unmodifiableSet(permissions);
	}

	@Override
	public String toString()
	{
		return String.format("%s (subjectSerialNumber=%s)", name, subjectSerialNumber);
	}
}
