/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsi.stamdata.replication.webservice;

import java.util.*;


/**
 * A helper class that formats dates for the Atom feed specification.
 * 
 * Atom feeds require a specific date format.
 * 
 * @author Thomas Børlum <thb@trifork.com>
 */
public class AtomDate
{
	/**
	 * Create the serialized string form from a java.util.Date
	 * 
	 * @param date A java.util.Date
	 * @return The serialized string form of the date
	 */
	public static String toString(Date date)
	{
		StringBuilder sb = new StringBuilder();
		Calendar c = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
		c.setTime(date);
		sb.append(c.get(Calendar.YEAR));
		sb.append('-');
		int f = c.get(Calendar.MONTH);
		if (f < 9) sb.append('0');
		sb.append(f + 1);
		sb.append('-');
		f = c.get(Calendar.DATE);
		if (f < 10) sb.append('0');
		sb.append(f);
		sb.append('T');
		f = c.get(Calendar.HOUR_OF_DAY);
		if (f < 10) sb.append('0');
		sb.append(f);
		sb.append(':');
		f = c.get(Calendar.MINUTE);
		if (f < 10) sb.append('0');
		sb.append(f);
		sb.append(':');
		f = c.get(Calendar.SECOND);
		if (f < 10) sb.append('0');
		sb.append(f);
		sb.append('.');
		f = c.get(Calendar.MILLISECOND);
		if (f < 100) sb.append('0');
		if (f < 10) sb.append('0');
		sb.append(f);
		sb.append('Z');
		return sb.toString();
	}
}
