/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsi.stamdata.replication.webservice;

import static java.lang.Long.parseLong;

import java.util.Date;

import org.apache.commons.lang.StringUtils;


/**
 * The format is:
 *
 * [-Updated Date-][-----ID-----]
 *
 * Each of the two section is 10 characters long and padded width 0's. The
 * updated date is represented in seconds since the last epoch.
 */
public class HistoryOffset {

	protected static int HISTORY_ID_SEGMENT_LENGTH = 10;
	protected static int SECS_TO_MILLIS = 1000;

	protected String recordID;
	protected Date modifiedDate;

	public HistoryOffset(String id, Date modifiedDate)
	{
		this.recordID = StringUtils.leftPad(id, 10, "0");
		this.modifiedDate = modifiedDate;
	}

	public HistoryOffset(String offsetString) {

		if (offsetString == null)
		{
			recordID = "0000000000";
			modifiedDate = new Date(0);
		}
		else
		{
			offsetString = StringUtils.leftPad(offsetString, 20, "0");

			String sinceDateParam = offsetString.substring(0, HISTORY_ID_SEGMENT_LENGTH);
			modifiedDate = new Date(parseLong(sinceDateParam) * SECS_TO_MILLIS);

			recordID = offsetString.substring(HISTORY_ID_SEGMENT_LENGTH);
		}
	}

	public Date getModifiedDate()
	{
		return modifiedDate;
	}

	public String getRecordID()
	{
		return recordID;
	}

	@Override
	public String toString()
	{
		return String.format("%010d%s", modifiedDate.getTime() / 1000, recordID);
	}
}
