/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.replication.tools;

import static junit.framework.Assert.assertTrue;

import java.io.File;
import java.util.Properties;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.google.common.io.Files;
import com.google.inject.Inject;

import dk.nsi.stamdata.replication.TestTableCreator;
import dk.nsi.stamdata.replication.webservice.GuiceTestRunner;
import dk.nsi.stamdata.testing.TestHelper;

@RunWith(GuiceTestRunner.class)
public class SchemaGeneratorTest
{
    @Inject
    TestTableCreator testTableCreator;

    String jdbcUrl;

    @Before
    public void setUp() throws Exception
    {
        Properties properties = TestHelper.loadProperties(this.getClass());
        jdbcUrl = properties.getProperty("db.connection.jdbcURL");
        String username = properties.getProperty("db.connection.username");
        String password = properties.getProperty("db.connection.password");
        if (username != null) {
            jdbcUrl = jdbcUrl + "?user="+username+"&password=";
            if (password != null) {
                jdbcUrl = jdbcUrl + password;
            }
        }
    }

    @Test
    @Ignore
    public void testThatWeCanGenerateTestSchema() throws Exception
    {
        long id = testTableCreator.createAndWhiteListForTestView(1L);
        //
        File tempDir = Files.createTempDir();
        String args[] = new String[2];
        args[0] = jdbcUrl;
        args[1] = tempDir.getAbsolutePath();
        DynamicSchemaGenerator.main(args);

        // Make sure we got a schema for our test table
        boolean found = false;
        File[] files = tempDir.listFiles();
        for (File file : files) {
            if (file.isDirectory() && file.getName().contains("testreg")) {
                String[] list = file.list();
                if ("testtype_v1.xsd".equals(list[0])) {
                    found = true;
                }
            }
        }
        assertTrue(found);
        FileUtils.deleteDirectory(tempDir);
        //
        testTableCreator.removeView(id);
    }
}
