/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;

import com.google.inject.Inject;
import com.google.inject.Provider;
import com.trifork.stamdata.models.YderVO;
import com.trifork.stamdata.persistence.PersistenceModule;

public class YderDAO {

    private final String SQL_YDER = " Id , HistIdYder , AmtKodeYder, AmtTxtYder, YdernrYder, PrakBetegn, AdrYder, PostnrYder, PostdistYder, TilgDatoYder, AfgDatoYder, HvdSpecKode, "+
             "HvdSpecTxt, HvdTlf, EmailYder, WWW, CVR, ModifiedDate, ValidFrom , ValidTo "+
            "FROM Yderregister_v3 ";

    private final Provider<Connection> connectionProvider;

    @Inject
    public YderDAO(Provider<Connection> connectionProvider)
    {
        this.connectionProvider = connectionProvider;
    }

    public YderVO findYder(String ydernummer, Date currentTime) throws SQLException {
        PreparedStatement preparedStatement = null;
        Connection connection = null;
        try {
          String queryString = "SELECT " + SQL_YDER + " WHERE YdernrYder = ? AND ValidFrom <= ? AND (ValidTo > ? OR ValidTo IS NULL)";
            connection = connectionProvider.get();
            preparedStatement = connection.prepareStatement(queryString);
            preparedStatement.setObject(1, ydernummer);
            preparedStatement.setObject(2, currentTime);
            preparedStatement.setObject(3, currentTime);
            ResultSet resultSet = preparedStatement.executeQuery();
            if (resultSet.next()) {
                if (!resultSet.isLast()) {
                    throw new IllegalStateException("More that one yder return for single ydernummer");
                }
                return mapYder(resultSet);
            } else {
                return null;
            }
        } finally {
            PersistenceModule.close(preparedStatement);
            PersistenceModule.close(connection);
        }
    }

    public YderVO mapYder(ResultSet resultSet) throws SQLException {
        YderVO yder = new YderVO();

        yder.setId(resultSet.getString("Id"));
        yder.setHistIdYder(resultSet.getString("HistIdYder"));
        yder.setAmtKodeYder(resultSet.getString("AmtKodeYder"));
        yder.setAmtTxtYder(resultSet.getString("AmtTxtYder"));
        yder.setYdernrYder(resultSet.getString("YdernrYder"));
        yder.setPrakBetegn(resultSet.getString("PrakBetegn"));
        yder.setAdrYder(resultSet.getString("AdrYder"));
        yder.setPostnrYder(resultSet.getString("PostnrYder"));
        yder.setPostdistYder(resultSet.getString("PostdistYder"));
        yder.setTilgDatoYder(resultSet.getString("TilgDatoYder"));
        yder.setAfgDatoYder(resultSet.getString("AfgDatoYder"));
        yder.setHvdSpecKode(resultSet.getString("HvdSpecKode"));
        yder.setHvdSpecTxt(resultSet.getString("HvdSpecTxt"));
        yder.setHvdTlf(resultSet.getString("HvdTlf"));
        yder.setEmailYder(resultSet.getString("EmailYder"));
        yder.setWWW(resultSet.getString("WWW"));
        yder.setCVR(resultSet.getString("CVR"));
        yder.setModifiedDate(resultSet.getDate("ModifiedDate"));
        yder.setValidFrom (resultSet.getDate("ValidFrom"));
        yder.setValidTo(resultSet.getDate("ValidTo"));

        return yder;
    }

}
