/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.mapping;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;

public class MunicipalityMapper {
	private static final Logger logger = Logger.getLogger(MunicipalityMapper.class);

	public String toCountyCode(String municipalityCode) {
		String countyCode = municipalityToCounty.getProperty(municipalityCode);
		if (countyCode == null) {
			logger.warn("Unknown municipality: " + municipalityCode + " setting countyCode to 1099");
			countyCode = "1099";
		}

		return countyCode;
	}

	private static Properties municipalityToCounty = new Properties();
	static {
		ClassLoader classLoader = MunicipalityMapper.class.getClassLoader();
		InputStream isInternal = classLoader.getResourceAsStream("municipalities-internal.properties");
		InputStream isExternal = classLoader.getResourceAsStream("municipalities-external.properties");

		try {
			municipalityToCounty.load(isInternal);

			// external file is optional, but will overwrite settings in the internal file
			if (isExternal != null) {
				municipalityToCounty.load(isExternal);
			}
		}
		catch (IOException e) {
			throw new RuntimeException("Problem loading one of the municipalities.properties file", e);
		}
		finally {
			IOUtils.closeQuietly(isExternal);
			IOUtils.closeQuietly(isInternal);
		}
	}
}
