/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.mapping.v100;

import dk.nsi.stamdata.cpr.models.HealthCareInformation;
import dk.nsi.stamdata.cpr.util.XMLCalendar;
import dk.oio.rep.medcom_sundcom_dk.xml.schemas._2007._02._01.ObjectFactory;
import dk.oio.rep.medcom_sundcom_dk.xml.schemas._2007._02._01.PersonPublicHealthInsuranceType;
import dk.oio.rep.medcom_sundcom_dk.xml.schemas._2007._02._01.PublicHealthInsuranceGroupIdentifierType;

public class HealthCareGroupToPersonPublicHealthInsuranceMapper {
    private static final String SYGESIKRINGSGRUPPE_1_FIELD_VALUE = "1";
    private static final String SYGESIKRINGSGRUPPE_2_FIELD_VALUE = "2";

    public PersonPublicHealthInsuranceType map(HealthCareInformation healthCareGroup) {
        PersonPublicHealthInsuranceType healthInsuranceType = new ObjectFactory().createPersonPublicHealthInsuranceType();
        // The key SSikrGrpKode is taken from "NSI - NOTUS Sikrede - def"
        String group = healthCareGroup.getGroup();
        if (SYGESIKRINGSGRUPPE_1_FIELD_VALUE.equals(group)) {
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_1);
        } else if (SYGESIKRINGSGRUPPE_2_FIELD_VALUE.equals(group)) {
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_2);
        } else {
            throw new IllegalStateException("Unknown value for SSikrGrpKode: " + group);
        }

        healthInsuranceType.setPublicHealthInsuranceGroupStartDate(XMLCalendar.
                newXMLGregorianCalendar(healthCareGroup.getStartDate()));
        return healthInsuranceType;
    }
}
