/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.mapping.v104a;

import dk.nsi.stamdata.cpr.models.HealthCareInformation;
import dk.nsi.stamdata.cpr.util.XMLCalendar;
import oio.medcom.cprservice._1_0_4a.PersonPublicHealthInsuranceType;
import oio.medcom.cprservice._1_0_4a.PublicHealthInsuranceGroupIdentifierType;
import oio.medcom.cprservice._1_0_4a.PublicHealthInsuranceStatusType;

public class HealthCareGroupToPersonPublicHealthInsuranceMapper {

    public static PersonPublicHealthInsuranceType map(HealthCareInformation healthCareInformation) {
        PersonPublicHealthInsuranceType healthInsuranceType = new PersonPublicHealthInsuranceType();

        switch (healthCareInformation.getGroup()) {
        case "0": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_0);
            break;
        case "1": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_1);
            break;
        case "2": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_2);
            break;
        case "4": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_4);
            break;
        case "5": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_5);
            break;
        case "6": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_6);
            break;
        case "7": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_7);
            break;
        case "8": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_8);
            break;
        case "9": 
            healthInsuranceType.setPublicHealthInsuranceGroupIdentifier(PublicHealthInsuranceGroupIdentifierType.SYGESIKRINGSGRUPPE_9);
            break;
        default:
            throw new IllegalStateException("Unknown value for SSikrGrpKode: " + healthCareInformation.getGroup());
        }
        healthInsuranceType.setPublicHealthInsuranceGroupStartDate(XMLCalendar.newXMLGregorianCalendar(healthCareInformation.getStartDate()));
        switch (healthCareInformation.getSStatus()) {
        case "D":
            healthInsuranceType.setPublicHealthInsuranceStatus(PublicHealthInsuranceStatusType.D);
            break;
        case "G":
            healthInsuranceType.setPublicHealthInsuranceStatus(PublicHealthInsuranceStatusType.G);
            break;
        case "U":
            healthInsuranceType.setPublicHealthInsuranceStatus(PublicHealthInsuranceStatusType.U);
            break;
        case "V":
            healthInsuranceType.setPublicHealthInsuranceStatus(PublicHealthInsuranceStatusType.V);
            break;
        }
        return healthInsuranceType;
    }

}
