/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.medcom;

import com.sun.xml.ws.developer.ValidationErrorHandler;
import org.apache.log4j.Logger;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

public class ValidationHandler extends ValidationErrorHandler {

    private static final Logger logger = Logger.getLogger(ValidationHandler.class);

    public static final String PARSE_ERROR = "SchemaValidationFatalError";
    public static final String REQUEST_DONE = "SchemaValidationRequestDone";
    public static final String REQUEST_PAYLOAD = "SchemaValidationRequestPayload";

    @Override
    public void warning(SAXParseException e) throws SAXException {}

    @Override
    public void error(SAXParseException e) throws SAXException {
        if (isResponse()) {

            logger.warn("Response validation error: " + e.getClass().getName() + ", msg=" + e.getMessage() +
                    ", request was: " + packet.invocationProperties.get(REQUEST_PAYLOAD));
            throw e;
        } else {
            logger.info("Request validation error: " + e.getClass().getName() + ", msg=" + e.getMessage());
            packet.invocationProperties.put(PARSE_ERROR, e);
        }
    }

    @Override
    public void fatalError(SAXParseException e) throws SAXException {
        if (isResponse()) {
            logger.warn("Response validation fatal: " + e.getClass().getName() + ", msg=" + e.getMessage() +
                    ", response was: " + packet.invocationProperties.get(REQUEST_PAYLOAD));
            throw e;
        } else {
            logger.info("Request validation fatal: " + e.getClass().getName() + ", msg=" + e.getMessage());
            packet.invocationProperties.put(PARSE_ERROR, e);
        }
    }

    private boolean isResponse() {
        if (packet.invocationProperties == null) {
            return false;
        }
        if (packet.invocationProperties.get(REQUEST_DONE) != null) {
            return true;
        } else {
            return false;
        }
    }

}
