/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.models;

import java.util.Date;

import org.apache.commons.lang.StringUtils;

public class HealthCareInformation {
    private final Date startDate;
    private final String group;
    private final String providerNo;
    private String sYdernrGl;
    private String sStatus;
    //Grænsegænger startdato
    private Date SSKGyldigFra = null;
    //Grænsegænger slutdato
    private Date SSKGyldigTil = null;
    //Grænsegængers statsborgerskab
    private String SBSStatsborgerskab = null;
    //Grænsegængers statsborgerskabs landekode
    private String SBSStatsborgerskabKode = null;
    //Grænsegængers bopælsland
    private String SSKBopelsLand = null;
    //Grænsegængers bopælslandekode
    private String SSKBopelsLAndKode = null;
    //Grænsegænger socialt sikret land
    private String SSLSocSikretLand = null;
    //Grænsegænger socialt sikret landekode
    private String SSLSocSikretLandKode = null;
    //Grænsegængers forsikringsinstans
    private String SSLForsikringsinstans = null;
    //Grænsegængers forsikringsinstans kode
    private String SSLForsikringsinstansKode = null;
    //Grænsegængers forsikringsnummer
    private String SSLForsikringsnr = null;
    
    public HealthCareInformation(Date startDate, String group, String providerNo) {
        this.startDate = startDate;
        this.group = group;
        this.providerNo = providerNo;
    }

    public Date getStartDate() {
        return startDate;
    }

    public String getGroup() {
        return group;
    }

    public String getProviderNo() {
        return providerNo;
    }

	public String getSYdernrGl() {
		return sYdernrGl;
	}

	public void setSYdernrGl(String sYdernrGl) {
		this.sYdernrGl = sYdernrGl;
	}

	public String getSStatus() {
		return sStatus;
	}

	public void setSStatus(String sStatus) {
		this.sStatus = sStatus;
	}

	public Date getSSKGyldigFra() {
		return SSKGyldigFra;
	}

	public void setSSKGyldigFra(Date sSKGyldigFra) {
		SSKGyldigFra = sSKGyldigFra;
	}

	public Date getSSKGyldigTil() {
		return SSKGyldigTil;
	}

	public void setSSKGyldigTil(Date sSKGyldigTil) {
		SSKGyldigTil = sSKGyldigTil;
	}

	public String getSBSStatsborgerskab() {
		return SBSStatsborgerskab;
	}

	public void setSBSStatsborgerskab(String sBSStatsborgerskab) {
		SBSStatsborgerskab = sBSStatsborgerskab;
	}

	public String getSBSStatsborgerskabKode() {
		return SBSStatsborgerskabKode;
	}

	public void setSBSStatsborgerskabKode(String sBSStatsborgerskabKode) {
		SBSStatsborgerskabKode = sBSStatsborgerskabKode;
	}

	public String getSSKBopelsLand() {
		return SSKBopelsLand;
	}

	public void setSSKBopelsLand(String sSKBopelsLand) {
		SSKBopelsLand = sSKBopelsLand;
	}

	public String getSSKBopelsLAndKode() {
		return SSKBopelsLAndKode;
	}

	public void setSSKBopelsLAndKode(String sSKBopelsLAndKode) {
		SSKBopelsLAndKode = sSKBopelsLAndKode;
	}

	public String getSSLSocSikretLand() {
		return SSLSocSikretLand;
	}

	public void setSSLSocSikretLand(String sSLSocSikretLand) {
		SSLSocSikretLand = sSLSocSikretLand;
	}

	public String getSSLSocSikretLandKode() {
		return SSLSocSikretLandKode;
	}

	public void setSSLSocSikretLandKode(String sSLSocSikretLandKode) {
		SSLSocSikretLandKode = sSLSocSikretLandKode;
	}

	public String getSSLForsikringsinstans() {
		return SSLForsikringsinstans;
	}

	public void setSSLForsikringsinstans(String sSLForsikringsinstans) {
		SSLForsikringsinstans = sSLForsikringsinstans;
	}

	public String getSSLForsikringsinstansKode() {
		return SSLForsikringsinstansKode;
	}

	public void setSSLForsikringsinstansKode(String sSLForsikringsinstansKode) {
		SSLForsikringsinstansKode = sSLForsikringsinstansKode;
	}

	public String getSSLForsikringsnr() {
		return SSLForsikringsnr;
	}

	public void setSSLForsikringsnr(String sSLForsikringsnr) {
		SSLForsikringsnr = sSLForsikringsnr;
	}

	@Override
	public String toString() {
		return "HealthCareInformation [startDate=" + startDate + ", group=" + group + ", providerNo=" + providerNo
				+ ", sYdernrGl=" + sYdernrGl + ", sStatus=" + sStatus + ", SSKGyldigFra=" + SSKGyldigFra
				+ ", SSKGyldigTil=" + SSKGyldigTil + ", SBSStatsborgerskab=" + SBSStatsborgerskab
				+ ", SBSStatsborgerskabKode=" + SBSStatsborgerskabKode + ", SSKBopelsLand=" + SSKBopelsLand
				+ ", SSKBopelsLAndKode=" + SSKBopelsLAndKode + ", SSLSocSikretLand=" + SSLSocSikretLand
				+ ", SSLSocSikretLandKode=" + SSLSocSikretLandKode + ", SSLForsikringsinstans=" + SSLForsikringsinstans
				+ ", SSLForsikringsinstansKode=" + SSLForsikringsinstansKode + ", SSLForsikringsnr=" + SSLForsikringsnr
				+ "]";
	}

    public boolean containsCitizenshipData() {
    	return StringUtils.isNotEmpty(getSBSStatsborgerskab()) && 
    		   StringUtils.isNotEmpty(getSBSStatsborgerskabKode());
    }

    public boolean containsResidenceCountryData() {
    	return StringUtils.isNotEmpty(getSSKBopelsLand()) && 
    		   StringUtils.isNotEmpty(getSSKBopelsLAndKode());
    }

    public boolean containsSocialSecurityData() {
    	return StringUtils.isNotEmpty(getSSLSocSikretLand()) && 
    		   StringUtils.isNotEmpty(getSSLSocSikretLandKode());
    }

    public boolean containsSocialSecurityAgenzyData() {
    	return StringUtils.isNotEmpty(getSSLForsikringsinstans()) &&
    		   StringUtils.isNotEmpty(getSSLForsikringsinstansKode()) &&
    		   StringUtils.isNotEmpty(getSSLForsikringsnr());
    }

    public boolean valid() {
    	return getSSKGyldigFra() != null && getSSKGyldigTil() != null;
    }

    public static boolean valid(HealthCareInformation healthCareInformation) {
        return healthCareInformation != null && healthCareInformation.valid(); 
    }

}