/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.pvit.v101;

import java.sql.SQLException;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.ws.Holder;

import dk.nsi._2011._09._23.stamdatacpr.CivilRegistrationNumberListPersonQueryType;
import dk.nsi._2011._09._23.stamdatacpr.NamePersonQueryType;
import dk.nsi._2011._09._23.stamdatacpr.PersonLookupRequestType;
import dk.nsi._2014._03._01.stamdatacpr.PersonLookupResponseType;
import dk.nsi.stamdata.cpr.pvit.v110.StamdataPersonLookupImpl;
import dk.nsi.stamdata.cpr.pvit.v110.StamdataPersonWithConsentResponseFinder;
import dk.nsi.stamdata.jaxws.generated.Header;
import dk.nsi.stamdata.jaxws.generated.Security;
import dk.sds.nsp.audit.Audit;
import dk.sds.nsp.audit.AuditBuilder;
import dk.sds.nsp.audit.AuditBuilder.TypeOfInformation;

public class StamdataLookupCommon101 {

    static public PersonLookupResponseType personDetails(Holder<Security> wsseHeader, Holder<Header> medcomHeader,
            PersonLookupRequestType request, String clientCVR, StamdataPersonResponseFinder stamdataPersonResponseFinder) throws SQLException, DatatypeConfigurationException {
    	
        if (request.getCivilRegistrationNumberPersonQuery() != null) {        	
        	logRequestedValue(stamdataPersonResponseFinder.getAuditlogText(), "cpr", request.getCivilRegistrationNumberPersonQuery());        			
            return stamdataPersonResponseFinder.answerCprRequest(clientCVR, request.getCivilRegistrationNumberPersonQuery());
        }
        
        if (request.getCivilRegistrationNumberListPersonQuery() != null) {
        	logRequestedValue(stamdataPersonResponseFinder.getAuditlogText(), "cpr list", request.getCivilRegistrationNumberListPersonQuery().getCivilRegistrationNumber().toString());        	
            return stamdataPersonResponseFinder.answerCivilRegistrationNumberListPersonRequest(clientCVR, request.getCivilRegistrationNumberListPersonQuery().getCivilRegistrationNumber());
        }
        if (request.getBirthDatePersonQuery() != null) {
        	logRequestedValue(stamdataPersonResponseFinder.getAuditlogText(), "birthdate", request.getBirthDatePersonQuery());      		
            return stamdataPersonResponseFinder.answerBirthDatePersonRequest(clientCVR, request.getBirthDatePersonQuery());
        }
        if (request.getNamePersonQuery() != null) {
        	logRequestedValue(stamdataPersonResponseFinder.getAuditlogText(), "name", (request.getNamePersonQuery().getPersonGivenName()+" "+request.getNamePersonQuery().getPersonMiddleName()+" "+request.getNamePersonQuery().getPersonSurnameName()).replaceAll("  ", " "));
            return stamdataPersonResponseFinder.answerNamePersonRequest(clientCVR, request.getNamePersonQuery());
        }
        throw new AssertionError("Unreachable point: exactly one of the previous clauses is true");
    }
    

	public static void logRequestedValue(String context, String key, String cpr) {
		TypeOfInformation informationType = AuditBuilder.TypeOfInformation.SensitivePersonalInformation;
    	String component = "SDM";
  	
        AuditBuilder auditBuilder = Audit.createAuditBuilder();
        auditBuilder.addAuditInformation(component, context, informationType, key, cpr);
	}
    public static void logRequestedValue(String context, String key, NamePersonQueryType name) {
		logRequestedValue(context, key, name.toString());
	}

	public static void logRequestedValue(String context, String key, XMLGregorianCalendar birthDate) {
		logRequestedValue(context, key, birthDate.toString());
	}

	public static void logRequestedValue(String context, String key, CivilRegistrationNumberListPersonQueryType cprList) {
		logRequestedValue(context, key, cprList.toString());
	}
}
