/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.pvit.v101;

import java.sql.SQLException;

import javax.inject.Inject;
import javax.jws.WebService;
import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.ws.Holder;

import org.apache.log4j.Logger;

import com.sun.xml.ws.developer.SchemaValidation;
import com.trifork.stamdata.jaxws.GuiceInstanceResolver;

import dk.nsi._2011._09._23.stamdatacpr.PersonLookupRequestType;
import dk.nsi._2014._03._01.stamdatacpr.DGWSFault;
import dk.nsi._2014._03._01.stamdatacpr.PersonLookupResponseType;
import dk.nsi._2014._03._01.stamdatacpr.StamdataPersonLookup;
import dk.nsi.stamdata.cpr.SoapUtils;
import dk.nsi.stamdata.cpr.medcom.FaultMessages;
import dk.nsi.stamdata.cpr.pvit.StamdataLookupCommon;
import dk.nsi.stamdata.jaxws.generated.Header;
import dk.nsi.stamdata.jaxws.generated.Security;
import dk.nsi.stamdata.security.Whitelisted;
import dk.sdsd.nsp.slalog.api.SLALogItem;
import dk.sosi.seal.model.SystemIDCard;
import dk.sosi.seal.model.constants.FaultCodeValues;

@WebService(endpointInterface="dk.nsi._2014._03._01.stamdatacpr.StamdataPersonLookup")
@GuiceInstanceResolver.GuiceWebservice
@SchemaValidation
public class StamdataPersonLookupImpl extends StamdataLookupCommon implements StamdataPersonLookup {
    private final static Logger logger = Logger.getLogger(StamdataPersonLookupImpl.class);
    private final StamdataPersonResponseFinder stamdataPersonResponseFinder;

    /**
     * Constructor for this implementation as Guice request scoped bean
     */
    @Inject
    StamdataPersonLookupImpl(SystemIDCard idCard, StamdataPersonResponseFinder stamdataPersonResponseFinder, SLALogItem slaLogItem) {
        super(idCard, slaLogItem);
        this.stamdataPersonResponseFinder = stamdataPersonResponseFinder;
    }

    @Override
    @Whitelisted(value="SDM")
    public PersonLookupResponseType getPersonDetails(Holder<Security> wsseHeader, Holder<Header> medcomHeader,
                                                     PersonLookupRequestType request) throws DGWSFault {
        SoapUtils.updateSlaLog(medcomHeader, "getPersonDetails", slaLogItem, clientCVR);
        // This has to be done according to the DGWS specifications
        SoapUtils.setHeadersToOutgoing(wsseHeader, medcomHeader);
        try {
        	stamdataPersonResponseFinder.setAuditlogText("SCES v1.0.1 getPersonDetails");
            return StamdataLookupCommon101.personDetails(wsseHeader, medcomHeader, request, clientCVR, stamdataPersonResponseFinder);
        } catch (SQLException e) {
            logger.error(e.getMessage(), e);
            throw SoapUtils.newDGWSFault(wsseHeader, medcomHeader, FaultMessages.INTERNAL_SERVER_ERROR, FaultCodeValues.PROCESSING_PROBLEM, DGWSFault.class);
        } catch (DatatypeConfigurationException e) {
            logger.error(e.getMessage(), e);
            throw SoapUtils.newDGWSFault(wsseHeader, medcomHeader, FaultMessages.INTERNAL_SERVER_ERROR, FaultCodeValues.PROCESSING_PROBLEM, DGWSFault.class);
        }
    }

}
