/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.security;

import com.google.inject.servlet.RequestScoped;

import dk.nsi._2018._06._08.stamdatacpr.DGWSFault;
import dk.nsi.stamdata.security.ClientVocesCvr;
import dk.nsi.stamdata.security.WhitelistService;
import dk.nsi.stamdata.security.Whitelisted;
import dk.sosi.seal.model.constants.FaultCodeValues;
import org.aopalliance.intercept.MethodInterceptor;
import org.aopalliance.intercept.MethodInvocation;
import org.apache.log4j.Logger;

import javax.inject.Inject;
import javax.inject.Provider;

@RequestScoped
public class WhitelistInterceptor implements MethodInterceptor {
    private static Logger logger = Logger.getLogger(WhitelistInterceptor.class);
    @Inject @ClientVocesCvr
    private Provider<String> clientCvrProvider;

    @Inject
    private Provider<WhitelistService> whitelistServiceProvider;

    @Override
    public Object invoke(MethodInvocation invocation) throws Throwable
    {
        Whitelisted whitelistedAnnotation = invocation.getMethod().getAnnotation(Whitelisted.class);
        String serviceName = whitelistedAnnotation.value();

        String clientCvr = clientCvrProvider.get();
        WhitelistService whitelistService = whitelistServiceProvider.get();

        Object result;
        if (whitelistService.isCvrWhitelisted(clientCvr, serviceName)) {
            result = invocation.proceed();
        } else {
            logger.error("CVR '" + clientCvr + "' is not in whitelist for component name " + serviceName);
            throw new DGWSFault("The request CVR number is not authorized to use this service.", FaultCodeValues.NOT_AUTHORIZED);
        }

        return result;

    }
}