/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.mapping;

import static org.junit.Assert.assertEquals;

import java.math.BigInteger;

import org.junit.Test;

import com.trifork.stamdata.models.YderVO;

import dk.nsi.stamdata.testing.Factories;
import dk.oio.rep.medcom_sundcom_dk.xml.schemas._2007._02._01.AssociatedGeneralPractitionerStructureType;

public class YderregisterRecordToAssociatedGeneralPractitionerMapperTest {

    @Test
    public void testCompleteMapping()
    {
        testSimpleMappingContainingAllFieldsHelper("123456", "Kvaksalverne A/S", "Galten", "kvak@salver.dk", "8464", "Hovedgaden 10", "86941234");
    }

    private void testSimpleMappingContainingAllFieldsHelper(
            String ydernrYder, String prakBetegn, String postdistYder, String emailYder, String postnrYder, String adrYder, String hvdTlf)
    {
        YderVO yder = Factories.createYder(ydernrYder);

        yder.setPrakBetegn(prakBetegn);
        yder.setPostdistYder(postdistYder);
        yder.setEmailYder(emailYder);
        yder.setPostnrYder(postnrYder);
        yder.setAdrYder(adrYder);
        yder.setHvdTlf(hvdTlf);

        YderregisterRecordToAssociatedGeneralPractitionerMapper mapper = new YderregisterRecordToAssociatedGeneralPractitionerMapper();
        AssociatedGeneralPractitionerStructureType xmlStructurer = mapper.map(yder, null);

        assertEquals(new BigInteger(ydernrYder), xmlStructurer.getAssociatedGeneralPractitionerIdentifier());
        assertEquals(prakBetegn, xmlStructurer.getAssociatedGeneralPractitionerOrganisationName());
        assertEquals(postdistYder, xmlStructurer.getDistrictName());
        assertEquals(emailYder, xmlStructurer.getEmailAddressIdentifier());
        assertEquals(postnrYder, xmlStructurer.getPostCodeIdentifier());
        assertEquals(adrYder, xmlStructurer.getStandardAddressIdentifier());
        assertEquals(hvdTlf, xmlStructurer.getTelephoneSubscriberIdentifier());
    }
}
