/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.util;

import static junit.framework.Assert.assertEquals;

import java.util.Date;

import javax.xml.ws.soap.SOAPFaultException;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.trifork.stamdata.models.PersonVO;

import dk.nsi.stamdata.cpr.util.UnreliableHandler;
import dk.nsi.stamdata.guice.GuiceTestRunner;

@RunWith(GuiceTestRunner.class)
public class UnreliableHandlerTest {

    UnreliableHandler unreliableHandler;

    @Before
    public void setUp() {
        unreliableHandler = new UnreliableHandler(null);
    }

    @Test
    public void testDefaultsUnreliableName() {
        PersonVO p = makeMinPerson();
        p.setUnreliable("Fornavn,Efternavn");
        unreliableHandler.defaultUnreliableFields(p);
        assertEquals("USIKKERT", p.getFornavn());
        assertEquals("USIKKERT", p.getEfternavn());
        assertEquals("Mellemnavn", p.getMellemnavn());
    }

    @Test
    public void testDefaultsUnreliableBirthDay() {
        PersonVO p = makeMinPerson();
        p.setUnreliable("Foedselsdato");
        unreliableHandler.defaultUnreliableFields(p);
        assertEquals("Fornavn", p.getFornavn());
        assertEquals(631148400000L, p.getFoedselsdato().getTime()); // 631148400000 => 1990-01-01 00:00:00
    }

    @Test(expected = SOAPFaultException.class)
    public void testThrowWhenNoDefault() {
        PersonVO p = makeMinPerson();
        p.setUnreliable("Status");
        unreliableHandler.defaultUnreliableFields(p);
    }

    private PersonVO makeMinPerson() {
        PersonVO p = new PersonVO();
        p.setFornavn("Fornavn");
        p.setMellemnavn("Mellemnavn");
        p.setEfternavn("Efternavn");
        p.setFoedselsdato(new Date());
        return p;
    }

}
