/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.trifork.stamdata.yder;

import static com.google.inject.name.Names.bindProperties;

import java.util.Properties;

import com.google.inject.AbstractModule;
import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.Stage;
import com.google.inject.name.Names;
import com.google.inject.servlet.GuiceServletContextListener;
import com.trifork.stamdata.ConfigurationLoader;
import com.trifork.stamdata.yder.models.DbModule;
import com.trifork.stamdata.yder.webservice.WebserviceModule;

import dk.nsi.stamdata.security.DenGodeWebServiceFilter;
import org.apache.log4j.Logger;

import javax.servlet.ServletContextEvent;


public class ComponentController extends GuiceServletContextListener
{
	private static final String COMPONENT_NAME = "stamdata-yder-lookup-ws";

    private static Logger logger;

    @Override
    public void contextDestroyed(ServletContextEvent servletContextEvent) {
        super.contextDestroyed(servletContextEvent);
        getLogger().info(servletContextEvent.getServletContext().getServletContextName() + " [Shutdown]");
    }

    @Override
    public void contextInitialized(ServletContextEvent servletContextEvent) {
        super.contextInitialized(servletContextEvent);
        getLogger().info(servletContextEvent.getServletContext().getServletContextName() + " [Started]");
    }

	@Override
	protected Injector getInjector()
	{
	    return Guice.createInjector(Stage.PRODUCTION, new ComponentModule(), new WebserviceModule());
	}


	public static class ComponentModule extends AbstractModule
	{
        @Override
        protected void configure()
        {
            Properties properties = ConfigurationLoader.loadForName(COMPONENT_NAME);
            getLogger().info("Loaded configuration for component: " + COMPONENT_NAME);
            bindProperties(binder(), properties);

            // A previous version of this component used the property
            // 'security' to determine what type of security to use (e.g. none, DGWS, Two-way-SSL).
            // To avoid the operator (Netic) to have to change deployment (i.e. puppet scripts) we
            // still support this property.

            String security = properties.getProperty("security");
            String useTestSTS = "false";
            String useMockTestSTS = "false";
            if ("dgwsMock".equalsIgnoreCase(security)) {
                useTestSTS = "true";
                useMockTestSTS = "true";
            } else if ("dgwsTest".equalsIgnoreCase(security)) {
                useTestSTS = "true";
            }
            getLogger().info("Using TestSTS: " + useTestSTS);
            getLogger().info("Using MockSTS: " + useMockTestSTS);
            bindConstant().annotatedWith(Names.named(DenGodeWebServiceFilter.USE_TEST_FEDERATION_PARAMETER)).to(useTestSTS);
            bindConstant().annotatedWith(Names.named(DenGodeWebServiceFilter.USE_MOCKED_FEDERATION_PARAMETER)).to(useMockTestSTS);

            install(new DbModule());
        }
	}

    private static Logger getLogger()
    {
        if (logger == null) {
            logger = Logger.getLogger(ComponentController.class);
        }
        return logger;
    }
}
